function eco561chpt7
%Define a matlab function

%Chapter 7, realizations of two MA(1) processes

epsilon = randn(151, 1);
%Simulate draws from a Gaussian white noise process

y1 = epsilon(2:end)+0.4*epsilon(1:end-1);
%Construct the series one

y2 = epsilon(2:end)+0.95*epsilon(1:end-1);
%Construct the series two

figure;
%Create the figure.

plot(1:length(y1), y1, 1:length(y2), y2, '--');
%Plot the series

title('Realizations of Two MA(1) Processes: \theta = 0.4 (solid line), \theta = 0.95 (dashed line)');
%Name the graph

xlabel('Time');
%Label the x-axis.

ylabel('Moving Average Processes');
%Label the y-axis.

print('-deps', 'eco561plot7-1');
%Print the graph as an eps file

close;
%Close the figure.

%Chapter 7, population autocorrelation and partial autocorrelation functions: MA(1) process, theta = 0.4

tau = 15;
%Define the number of lags

theta = 0.4;
%Define theta

rho = zeros(tau, 1);
%Allocate a vector to store population autocorrelations

rho(1) = theta/(1+theta^2);
%Calculate the population autocorrelations

partial = eco561partial(rho);
%Calculate the partial autocorrelations from autocorrelations

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

bar(rho);
%Plot the graph

title('Population Autocorrelation and Partial Autocorrelation Functions: MA(1) Process, \theta = 0.4');
%Name the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Autocorrelation');
%Label the y-axis.

subplot(2, 1, 2);
%Plot in the bottom panel

bar(partial);
%Plot the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Partial Autocorrelation');
%Label the y-axis.

print('-deps', 'eco561plot7-2');
%Print the graph as an eps file

close;
%Close the figure.

%Chapter 7, population autocorrelation and partial autocorrelation functions: MA(1) process, theta = 0.95

theta = 0.95;
%Define theta

rho = zeros(tau, 1);
%Allocate a vector to store population autocorrelations

rho(1) = theta/(1+theta^2);
%Calculate the population autocorrelations

partial = eco561partial(rho);
%Calculate the partial autocorrelations from autocorrelations

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

bar(rho);
%Plot the graph

title('Population Autocorrelation and Partial Autocorrelation Functions: MA(1) Process, \theta = 0.95');
%Name the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Autocorrelation');
%Label the y-axis.

subplot(2, 1, 2);
%Plot in the bottom panel

bar(partial);
%Plot the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Partial Autocorrelation');
%Label the y-axis.

print('-deps', 'eco561plot7-3');
%Print the graph as an eps file

close;
%Close the figure.

%Chapter 7, realizations of two AR(1) processes

epsilon = randn(150, 1);
%Simulate draws from a Gaussian white noise process

y1 = zeros(length(epsilon), 1);
%Allocate a vector to store the series one

y2 = zeros(length(epsilon), 1);
%Allocate a vector to store the series two

y1(1) = epsilon(1);
%Set the starting value of series one

y2(1) = epsilon(1);
%Set the starting value of series two

for i = 2:length(epsilon);
%Calculate the other values iteratively

y1(i) = 0.4*y1(i-1)+epsilon(i);
%Construct the series one

y2(i) = 0.95*y2(i-1)+epsilon(i);
%Construct the series two

end;
%End the loop

figure;
%Create the figure.

plot(1:length(y1), y1, 1:length(y2), y2, '--');
%Plot the series

title('Realizations of Two AR(1) Processes: \phi = 0.4 (solid line), \phi = 0.95 (dashed line)');
%Name the graph

xlabel('Time');
%Label the x-axis.

ylabel('Autoregressive Processes');
%Label the y-axis.

print('-deps', 'eco561plot7-4');
%Print the graph as an eps file

close;
%Close the figure.

%Chapter 7, population autocorrelation and partial autocorrelation functions: AR(1) process, phi = 0.4

tau = 15;
%Define the number of lags

phi = 0.4;
%Define phi

rho = phi.^(1:tau)';
%Calculate the population autocorrelations

partial = eco561partial(rho);
%Calculate the partial autocorrelations from autocorrelations

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

bar(rho);
%Plot the graph

title('Population Autocorrelation and Partial Autocorrelation Functions: AR(1) Process, \phi = 0.4');
%Name the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Autocorrelation');
%Label the y-axis.

subplot(2, 1, 2);
%Plot in the bottom panel

bar(partial);
%Plot the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Partial Autocorrelation');
%Label the y-axis.

print('-deps', 'eco561plot7-5');
%Print the graph as an eps file

close;
%Close the figure.

%Chapter 7, population autocorrelation and partial autocorrelation functions: AR(1) process, phi = 0.95

phi = 0.95;
%Define phi

rho = phi.^(1:tau)';
%Calculate the population autocorrelations

partial = eco561partial(rho);
%Calculate the partial autocorrelations from autocorrelations

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

bar(rho);
%Plot the graph

title('Population Autocorrelation and Partial Autocorrelation Functions: AR(1) Process, \phi = 0.95');
%Name the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Autocorrelation');
%Label the y-axis.

subplot(2, 1, 2);
%Plot in the bottom panel

bar(partial);
%Plot the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Partial Autocorrelation');
%Label the y-axis.

print('-deps', 'eco561plot7-6');
%Print the graph as an eps file

close;
%Close the figure.

%Chapter 7, population autocorrelation and partial autocorrelation functions: AR(2) process with complex roots

tau = 30;
%Define the number of lags

phi1 = 1.5;
%Define phi1

phi2 = -0.9;
%Define phi2

rho = zeros(tau, 1);
%Allocate a vector to store the population autocorrelations

rho(1) = phi1/(1-phi2);
%Calculate the autocorrelation at lag one

rho(2) = phi1*rho(1)+phi2*1;
%Calculate the autocorrelation at lag two

for i = 3:tau;
%Calculate the autocorrelations at other lags

rho(i) = phi1*rho(i-1)+phi2*rho(i-2);
%Calculate the autocorrelations iteratively

end;
%End the loop

partial = eco561partial(rho);
%Calculate the partial autocorrelations from autocorrelations

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

bar(rho);
%Plot the graph

title('Population Autocorrelation and Partial Autocorrelation Functions: AR(2) Process');
%Name the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Autocorrelation');
%Label the y-axis.

subplot(2, 1, 2);
%Plot in the bottom panel

bar(partial);
%Plot the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Partial Autocorrelation');
%Label the y-axis.

print('-deps', 'eco561plot7-7');
%Print the graph as an eps file

close;
%Close the figure.

%Chapter 7, application: specifying and estimating models for employment forecasting

data = load('CAEMP.DAT', '-ascii');
%Read the data set called ``CAEMP.DAT'' in ascii form.

y = data(5:132);
%Define the series

maxq = 8;
%Define the maximum order of MA

exitflag = zeros(maxq, 1);
%Allocate the vector to store exitflag

aic = zeros(maxq, 1);
%Allocate the vector to store AIC

sic = zeros(maxq, 1);
%Allocate the vector to store SIC

for q = 1:maxq;
%Define the order of MA

[b, fval, exitflag(q), output] = fminsearch(@eco561ma, [mean(y); zeros(q, 1)], optimset('MaxFunEvals', 2*(q+1)*200, 'MaxIter', 2*(q+1)*200), y, q);
%Estimate the coefficients

mu = b(1)
%Extract mu

theta = b(2:end)
%Extract theta

maroots = roots([1; theta])
%Calculate the inverted MA roots

absmaroots = abs(maroots)
%Calculate the absolute values of the inverted MA roots

e = zeros(length(y)+q, 1);
%Allocate the vector to store the residuals

for i = 1:length(y);
%Iterate through lags

e(i+q) = y(i)-mu-sum(theta.*e(i+q-1:-1:i));
%Construct the residuals

end;
%End the loop

e = e(q+1:end);
%Remove the starting values

yhat = y-e;
%Construct the fitted values

aic(q) = log(exp(2*length(b)/length(y))*sum(e.^2)/length(y));
%AIC

sic(q) = log(length(y)^(length(b)/length(y))*sum(e.^2)/length(y));
%SIC

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

plot(62+1/4:1/4:93+4/4, y, '-', 62+1/4:1/4:93+4/4, yhat, '--')
%Plot the acutal and fitted values of y

title(['Employment: MA(' num2str(q) ') Model, Residual Plot']);
%Name the graph

xlabel('Actual (solid line) and fitted (dashed line) values of y');
%Annotate the graph

subplot(2, 1, 2);
%Plot in the bottom panel

plot(62+1/4:1/4:93+4/4, e)
%Plot the residuals

xlabel('Residuals');
%Annotate the graph

print('-deps', ['eco561plot7-' num2str(7+2*q-1)]);
%Print the graph as an eps file

close;
%Close the figure.

tau = 12;
%Define the number of lags

[rho, qlb, partial] = eco561auto(e, tau);
%Obtain the sample autocorrelations, Ljung-Box Q-statistics, and sample partial autocorrelations

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

bar(rho);
%Plot the graph

hold on;
%Plot without erasing the previous drawings

plot(1:tau, repmat(2/sqrt(length(y)), [tau 1]), 1:tau, repmat(-2/sqrt(length(y)), [tau 1]));
%Plot the two standard error bands

title(['Employment: MA(' num2str(q) ') Model, Residual Sample Autocorrelations and Partial Autocorrelations']);
%Name the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Sample Autocorrelation');
%Label the y-axis.

subplot(2, 1, 2);
%Plot in the bottom panel

bar(partial);
%Plot the graph

hold on;
%Plot without erasing the previous drawings

plot(1:tau, repmat(2/sqrt(length(y)), [tau 1]), 1:tau, repmat(-2/sqrt(length(y)), [tau 1]));
%Plot the two standard error bands

xlabel('Displacement');
%Label the x-axis.

ylabel('Sample Partial Autocorrelation');
%Label the y-axis.

print('-deps', ['eco561plot7-' num2str(7+2*q)]);
%Print the graph as an eps file

close;
%Close the figure.

end;
%End the loop

aic
%List the AICs

sic
%List the SICs

exitflag
%List the exitflags

data = load('CAEMP.DAT', '-ascii');
%Read the data set called ``CAEMP.DAT'' in ascii form.

series = data(5:132);
%Define the series

maxp = 8;
%Define the maximum order of AR

aic = zeros(maxp, 1);
%Allocate the vector to store AIC

sic = zeros(maxp, 1);
%Allocate the vector to store SIC

for p = 1:maxp;
%Define the order of AR

y = series(p+1:end);
%Define the dependent variable

x = ones(length(y), 1);
%Define the independent variable

for i = 1:p;
%Iterate through lags

x = [x series(p+1-i:end-i)];
%Add lags of the dependent variable

end;
%End loop

b = (x'*x)^(-1)*x'*y;
%Estimate the coefficients

phi = b(2:end)
%Extract phi

mu = b(1)/sum([1; -phi])
%Extract mu

arroots = roots([1; -phi])
%Calculate the inverted AR roots

absarroots = abs(arroots)
%Calculate the absolute values of the inverted AR roots

yhat = x*b;
%Calculate the fitted values

e = y-yhat;
%Calculate the residuals

aic(p) = log(exp(2*length(b)/length(y))*sum(e.^2)/length(y));
%AIC

sic(p) = log(length(y)^(length(b)/length(y))*sum(e.^2)/length(y));
%SIC

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

plot(62+1/4+1/4*p:1/4:93+4/4, y, '-', 62+1/4+1/4*p:1/4:93+4/4, yhat, '--')
%Plot the acutal and fitted values of y

title(['Employment: AR(' num2str(p) ') Model, Residual Plot']);
%Name the graph

xlabel('Actual (solid line) and fitted (dashed line) values of y');
%Annotate the graph

subplot(2, 1, 2);
%Plot in the bottom panel

plot(62+1/4+1/4*p:1/4:93+4/4, e)
%Plot the residuals

xlabel('Residuals');
%Annotate the graph

print('-deps', ['eco561plot7-' num2str(23+2*p-1)]);
%Print the graph as an eps file

close;
%Close the figure.

tau = 12;
%Define the number of lags

[rho, qlb, partial] = eco561auto(e, tau);
%Obtain the sample autocorrelations, Ljung-Box Q-statistics, and sample partial autocorrelations

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

bar(rho);
%Plot the graph

hold on;
%Plot without erasing the previous drawings

plot(1:tau, repmat(2/sqrt(length(y)), [tau 1]), 1:tau, repmat(-2/sqrt(length(y)), [tau 1]));
%Plot the two standard error bands

title(['Employment: AR(' num2str(p) ') Model, Residual Sample Autocorrelations and Partial Autocorrelations']);
%Name the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Sample Autocorrelation');
%Label the y-axis.

subplot(2, 1, 2);
%Plot in the bottom panel

bar(partial);
%Plot the graph

hold on;
%Plot without erasing the previous drawings

plot(1:tau, repmat(2/sqrt(length(y)), [tau 1]), 1:tau, repmat(-2/sqrt(length(y)), [tau 1]));
%Plot the two standard error bands

xlabel('Displacement');
%Label the x-axis.

ylabel('Sample Partial Autocorrelation');
%Label the y-axis.

print('-deps', ['eco561plot7-' num2str(23+2*p)]);
%Print the graph as an eps file

close;
%Close the figure.

end;
%End the loop

aic
%List the AICs

sic
%List the SICs

data = load('CAEMP.DAT', '-ascii');
%Read the data set called ``CAEMP.DAT'' in ascii form.

series = data(5:132);
%Define the series

maxp = 4;
%Define the maximum order of AR

maxq = 4;
%Define the maximum order of MA

exitflag = zeros(maxp, maxq);
%Allocate the matrix to store exitflag

aic = zeros(maxp, maxq);
%Allocate the matrix to store AIC

sic = zeros(maxp, maxq);
%Allocate the matrix to store SIC

for p = 1:maxp;
%Iterate through AR orders

y = series(1+p:end);
%Define the dependent variable

x = ones(length(y), 1);
%Define the independent variable

for i = 1:p;
%Iterate through lags

x = [x series(1+p-i:end-i)];
%Add lags of the dependent variable

end;
%End the loop

b = (x'*x)^(-1)*x'*y;
%Estimate the coefficients

phi = b(2:end);
%Extract phi

mu = b(1)/(sum([1; -phi]));
%Extract mu

y = series;
%Define the series

for q = 1:maxq;
%Iterate through MA orders

[b, fval, exitflag(p, q), output] = fminsearch(@eco561arma, [mu; phi; zeros(q, 1)], optimset('MaxFunEvals', 8*(p+q+1)*200, 'MaxIter', 8*(p+q+1)*200), y, p, q);
%Estimate the coefficients

mu = b(1)
%Extract mu

phi = b(2:1+p)
%Extract phi

arroots = roots([1; -phi])
%Calculate the inverted AR roots

absarroots = abs(arroots)
%Calculate the absolute values of the inverted AR roots

theta = b(1+p+1:end)
%Extract theta

maroots = roots([1; theta])
%Calculate the inverted MA roots

absmaroots = abs(maroots)
%Calculate the absolute values of the inverted MA roots

e = zeros(length(y)-p+q, 1);
%Allocate the vector to store the residuals

for i = 1+p:length(y);
%Iterate through lags

e(i-p+q) = y(i)-mu-sum(phi.*(y(i-1:-1:i-p)-mu))-sum(theta.*e(i-p+q-1:-1:i-p));
%Construct the residuals

end;
%End the loop

e = e(q+1:end);
%Remove the starting values

yhat = y(1+p:end)-e;
%Construct the fitted values

aic(p, q) = log(exp(2*length(b)/length(e))*sum(e.^2)/length(e));
%AIC

sic(p, q) = log(length(e)^(length(b)/length(e))*sum(e.^2)/length(e));
%SIC

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

plot(62+1/4+1/4*p:1/4:93+4/4, y(1+p:end), '-', 62+1/4+1/4*p:1/4:93+4/4, yhat, '--')
%Plot the acutal and fitted values of y

title(['Employment: ARMA(' num2str(p) ',' num2str(q) ') Model, Residual Plot']);
%Name the graph

xlabel('Actual (solid line) and fitted (dashed line) values of y');
%Annotate the graph

subplot(2, 1, 2);
%Plot in the bottom panel

plot(62+1/4+1/4*p:1/4:93+4/4, e)
%Plot the residuals

xlabel('Residuals');
%Annotate the graph

print('-deps', ['eco561plot7-' num2str(39+2*((p-1)*maxq+q)-1)]);
%Print the graph as an eps file

close;
%Close the figure.

tau = 12;
%Define the number of lags

[rho, qlb, partial] = eco561auto(e, tau);
%Obtain the sample autocorrelations, Ljung-Box Q-statistics, and sample partial autocorrelations

figure;
%Create the figure.

subplot(2, 1, 1);
%Plot in the top panel

bar(rho);
%Plot the graph

hold on;
%Plot without erasing the previous drawings

plot(1:tau, repmat(2/sqrt(length(e)), [tau 1]), 1:tau, repmat(-2/sqrt(length(e)), [tau 1]));
%Plot the two standard error bands

title(['Employment: ARMA(' num2str(p) ',' num2str(q) ') Model, Residual Sample Autocorrelations and Partial Autocorrelations']);
%Name the graph

xlabel('Displacement');
%Label the x-axis.

ylabel('Sample Autocorrelation');
%Label the y-axis.

subplot(2, 1, 2);
%Plot in the bottom panel

bar(partial);
%Plot the graph

hold on;
%Plot without erasing the previous drawings

plot(1:tau, repmat(2/sqrt(length(e)), [tau 1]), 1:tau, repmat(-2/sqrt(length(e)), [tau 1]));
%Plot the two standard error bands

xlabel('Displacement');
%Label the x-axis.

ylabel('Sample Partial Autocorrelation');
%Label the y-axis.

print('-deps', ['eco561plot7-' num2str(39+2*((p-1)*maxq+q))]);
%Print the graph as an eps file

close;
%Close the figure.

end;
%End the loop

end;
%End the loop

aic
%List the AICs

sic
%List the SICs

exitflag
%List the exitflags

